CalendarHeaderProvider class
Provider that holds the currently selected month used by the calendar header UI and exposes helpers to change it.
Use this provider to read or change the month shown in the month/year picker UI.
- Inheritance
-
- Object
- ChangeNotifier
- CalendarHeaderProvider
Constructors
- CalendarHeaderProvider(DateTime initialMonth)
-
Creates a CalendarHeaderProvider initialized to
initialMonth.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedMonth → DateTime
-
The currently selected month (year + month, day is ignored).
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
nextMonth(
) → void - Move the selected month forward by one month and notify listeners.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
previousMonth(
) → void - Move the selected month back by one month and notify listeners.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setMonth(
DateTime month) → void - Replace the currently selected month and notify listeners.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited