autoScroll property

bool autoScroll
final

If true the view will automatically scroll to initialDate when first built. Defaults to true but can be set to false to let external layout or controllers manage initial offset.

Implementation

final bool autoScroll;