initialDate property
Optional date to scroll to on first build (if autoScroll is true) and earliest selectable date.
Implementation
final DateTime? initialDate;
Optional date to scroll to on first build (if autoScroll is true) and earliest selectable date.
final DateTime? initialDate;