selectedWeekDaysTextStyle property
Text style used for the weekday label in the selected cell.
Implementation
final TextStyle? selectedWeekDaysTextStyle;
Text style used for the weekday label in the selected cell.
final TextStyle? selectedWeekDaysTextStyle;